Chat

Struct Chat 

pub struct Chat { /* private fields */ }

Implementations

Source

impl Chat

pub fn new<T>(model: T) -> Self
where T: Into<String>,

Creates a new Chat with the selected model.

Example
use rustylms::{
    chat::Chat,
    lmsserver::LMSServer
};

let server = LMSServer::new("http://localhost:1234");
let chat = Chat::new("model-name").system_prompt("You are a helpful assistant.").user_prompt("Why does iron rust?");
let completion = chat.get_completions(&server).await.expect("Could not get completions");

println!("From assistant: {}", completion.get_message().unwrap().content);
pub fn temperature(self, temperature: f32) -> Self

Sets the temperature of the model. The default value for this is 0.7.

pub fn max_tokens(self, max_tokens: i32) -> Self

Sets the maximum tokens a completion can generate. The default value is -1 meaning no limit.

pub fn system_prompt<T>(self, system_prompt: T) -> Self
where T: Into<String>,

This function adds a system prompt to the messages.

NOTE: This function doesn’t clear the messages array before adding the system prompt!

pub fn user_prompt<T>(self, user_prompt: T) -> Self
where T: Into<String>,

This function adds a user prompt to the messages.

NOTE: This function doesn’t clear the messages array before adding the user prompt!

pub fn clear_messages(&mut self)

Clears all messages in the chat including system prompts.

pub fn add_message(&mut self, message: Message)

Adds the provided Message to the chat.

pub fn add_system_message<T>(&mut self, message: T)
where T: Into<String>,

Adds the provided message content as a system message.

pub fn add_assistant_message<T>(&mut self, message: T)
where T: Into<String>,

Adds the provided message content as a message from the assistant.

pub fn add_user_message<T>(&mut self, message: T)
where T: Into<String>,

Adds the provided message content as a message from the user.

pub async fn get_completions( &self, server: &LMSServer, ) -> Result<ChatCompletionsResponse>

Gets the completion from the server by sending the current Chat struct.